@@ -12,10 +12,15 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import json
+import threading
 
+import cachetools
 from gnocchiclient import client
 from gnocchiclient import exceptions
-from oslo_serialization import jsonutils
+from keystoneauth1 import exceptions as ka_exceptions
+from oslo_config import cfg
+from oslo_log import log
 import pecan
 import wsme
 from wsme import types as wtypes
@@ -24,6 +29,19 @@ from aodh.api.controllers.v2 import base
 from aodh.api.controllers.v2 import utils as v2_utils
 from aodh import keystone_client
 
+LOG = log.getLogger(__name__)
+
+GNOCCHI_OPTS = [
+    cfg.StrOpt('gnocchi_external_project_owner',
+               default="service",
+               help='Project name of resources creator in Gnocchi. '
+               '(For example the Ceilometer project name'),
+    cfg.StrOpt('gnocchi_external_domain_name',
+               default="Default",
+               help='Domain name of resources creator in Gnocchi. '
+               '(For example, default or service_domain'),
+]
+
 
 class GnocchiUnavailable(Exception):
     code = 503
@@ -47,6 +65,9 @@ class AlarmGnocchiThresholdRule(base.AlarmRule):
     granularity = wsme.wsattr(wtypes.IntegerType(minimum=1), default=60)
     "The time range in seconds over which query"
 
+    cache = cachetools.TTLCache(maxsize=1, ttl=3600)
+    lock = threading.RLock()
+
     @classmethod
     def validate_alarm(cls, alarm):
         alarm_rule = getattr(alarm, "%s_rule" % alarm.type)
@@ -56,17 +77,15 @@ class AlarmGnocchiThresholdRule(base.AlarmRule):
                 'aggregation_method should be in %s not %s' % (
                     cls._get_aggregation_methods(), aggregation_method))
 
-    # NOTE(sileht): once cachetools is in the requirements
-    # enable it
-    # @cachetools.ttl_cache(maxsize=1, ttl=600)
     @staticmethod
+    @cachetools.cached(cache, lock=lock)
     def _get_aggregation_methods():
         conf = pecan.request.cfg
         gnocchi_client = client.Client(
             '1', keystone_client.get_session(conf),
-            interface=conf.service_credentials.interface,
-            region_name=conf.service_credentials.region_name)
-
+            adapter_options={
+                'interface': conf.service_credentials.interface,
+                'region_name': conf.service_credentials.region_name})
         try:
             return gnocchi_client.capabilities.list().get(
                 'aggregation_methods', [])
@@ -95,26 +114,6 @@ class MetricOfResourceRule(AlarmGnocchiThresholdRule):
                                        'resource_type'])
         return rule
 
-    @classmethod
-    def validate_alarm(cls, alarm):
-        super(MetricOfResourceRule,
-              cls).validate_alarm(alarm)
-
-        conf = pecan.request.cfg
-        gnocchi_client = client.Client(
-            '1', keystone_client.get_session(conf),
-            interface=conf.service_credentials.interface,
-            region_name=conf.service_credentials.region_name)
-
-        rule = alarm.gnocchi_resources_threshold_rule
-        try:
-            gnocchi_client.resource.get(rule.resource_type,
-                                        rule.resource_id)
-        except exceptions.ClientException as e:
-            raise base.ClientSideError(e.message, status_code=e.code)
-        except Exception as e:
-            raise GnocchiUnavailable(e)
-
 
 class AggregationMetricByResourcesLookupRule(AlarmGnocchiThresholdRule):
     metric = wsme.wsattr(wtypes.text, mandatory=True)
@@ -138,6 +137,29 @@ class AggregationMetricByResourcesLookupRule(AlarmGnocchiThresholdRule):
                                        'resource_type'])
         return rule
 
+    cache = cachetools.TTLCache(maxsize=1, ttl=3600)
+    lock = threading.RLock()
+
+    @staticmethod
+    @cachetools.cached(cache, lock=lock)
+    def get_external_project_owner():
+        kc = keystone_client.get_client(pecan.request.cfg)
+        project_name = pecan.request.cfg.api.gnocchi_external_project_owner
+        domain_name = pecan.request.cfg.api.gnocchi_external_domain_name
+        try:
+            domains = kc.domains.list(name=domain_name)
+            project = kc.projects.find(
+                name=project_name,
+                domain_id=domains[0].id)
+            return project.id
+        except ka_exceptions.NotFound:
+            LOG.warning("Unable to get domain or project information. "
+                        "domain_name : %(domain_name)s, "
+                        "project_name : %(project_name)s",
+                        {'domain_name': domain_name,
+                         'project_name': project_name})
+            return None
+
     @classmethod
     def validate_alarm(cls, alarm):
         super(AggregationMetricByResourcesLookupRule,
@@ -147,31 +169,51 @@ class AggregationMetricByResourcesLookupRule(AlarmGnocchiThresholdRule):
 
         # check the query string is a valid json
         try:
-            query = jsonutils.loads(rule.query)
+            query = json.loads(rule.query)
         except ValueError:
             raise wsme.exc.InvalidInput('rule/query', rule.query)
 
+        conf = pecan.request.cfg
+
         # Scope the alarm to the project id if needed
         auth_project = v2_utils.get_auth_project(alarm.project_id)
         if auth_project:
-            query = {"and": [{"=": {"created_by_project_id": auth_project}},
-                             query]}
-            rule.query = jsonutils.dumps(query)
 
-        conf = pecan.request.cfg
+            perms_filter = {"=": {"created_by_project_id": auth_project}}
+
+            external_project_owner = cls.get_external_project_owner()
+            if external_project_owner:
+                perms_filter = {"or": [
+                    perms_filter,
+                    {"and": [
+                        {"=": {"created_by_project_id":
+                               external_project_owner}},
+                        {"=": {"project_id": auth_project}}]}
+                ]}
+
+            query = {"and": [perms_filter, query]}
+            rule.query = json.dumps(query)
+
         gnocchi_client = client.Client(
             '1', keystone_client.get_session(conf),
-            interface=conf.service_credentials.interface,
-            region_name=conf.service_credentials.region_name)
-
+            adapter_options={
+                'interface': conf.service_credentials.interface,
+                'region_name': conf.service_credentials.region_name})
         try:
             gnocchi_client.metric.aggregation(
                 metrics=rule.metric,
                 query=query,
                 aggregation=rule.aggregation_method,
                 needed_overlap=0,
+                start="-1 day",
+                stop="now",
                 resource_type=rule.resource_type)
         except exceptions.ClientException as e:
+            if e.code == 404:
+                # NOTE(sileht): We are fine here, we just want to ensure the
+                # 'query' payload is valid for Gnocchi If the metric
+                # doesn't exists yet, it doesn't matter
+                return
             raise base.ClientSideError(e.message, status_code=e.code)
         except Exception as e:
             raise GnocchiUnavailable(e)
