@@ -4,12 +4,12 @@
 # looks like
 #
 # [[local|localrc]]
-# enable_plugin aodh git://git.openstack.org/openstack/aodh
+# enable_plugin aodh https://opendev.org/openstack/aodh
 #
 # By default all aodh services are started (see
 # devstack/settings).
 #
-#   AODH_BACKEND:            Database backend (e.g. 'mysql', 'mongodb')
+#   AODH_BACKEND:            Database backend (e.g. 'mysql')
 #   AODH_COORDINATION_URL:   URL for group membership service provided by tooz.
 
 # Support potential entry-points console scripts in VENV or not
@@ -50,28 +50,6 @@ function aodh_service_url {
 }
 
 
-# _install_mongdb - Install mongodb and python lib.
-function _aodh_install_mongodb {
-    # Server package is the same on all
-    local packages=mongodb-server
-
-    if is_fedora; then
-        # mongodb client
-        packages="${packages} mongodb"
-    fi
-
-    install_package ${packages}
-
-    if is_fedora; then
-        restart_service mongod
-    else
-        restart_service mongodb
-    fi
-
-    # give time for service to restart
-    sleep 5
-}
-
 # _install_redis() - Install the redis server and python lib.
 function _aodh_install_redis {
     if is_ubuntu; then
@@ -91,7 +69,6 @@ function _aodh_config_apache_wsgi {
     sudo mkdir -p $AODH_WSGI_DIR
 
     local aodh_apache_conf=$(apache_site_config_for aodh)
-    local apache_version=$(get_apache_version)
     local venv_path=""
 
     # Copy proxy vhost and wsgi file
@@ -102,18 +79,12 @@ function _aodh_config_apache_wsgi {
     fi
 
     sudo cp $AODH_DIR/devstack/apache-aodh.template $aodh_apache_conf
-    if [ "$AODH_BACKEND" = 'hbase' ] ; then
-        # Use one process to have single in-memory DB instance for data consistency
-        AODH_API_WORKERS=1
-    else
-        AODH_API_WORKERS=$API_WORKERS
-    fi
     sudo sed -e "
         s|%PORT%|$AODH_SERVICE_PORT|g;
         s|%APACHE_NAME%|$APACHE_NAME|g;
         s|%WSGIAPP%|$AODH_WSGI_DIR/app|g;
         s|%USER%|$STACK_USER|g;
-        s|%APIWORKERS%|$AODH_API_WORKERS|g;
+        s|%APIWORKERS%|$API_WORKERS|g;
         s|%VIRTUALENV%|$venv_path|g
     " -i $aodh_apache_conf
 }
@@ -127,14 +98,6 @@ function _aodh_prepare_coordination {
     fi
 }
 
-# Install required services for storage backends
-function _aodh_prepare_storage_backend {
-    if [ "$AODH_BACKEND" = 'mongodb' ] ; then
-        pip_install_gr pymongo
-        _aodh_install_mongodb
-    fi
-}
-
 # Create aodh related accounts in Keystone
 function _aodh_create_accounts {
     if is_service_enabled aodh-api; then
@@ -170,9 +133,6 @@ function _aodh_cleanup_apache_wsgi {
 # cleanup_aodh() - Remove residual data files, anything left over
 # from previous runs that a clean run would need to clean up
 function cleanup_aodh {
-    if [ "$AODH_BACKEND" = 'mongodb' ] ; then
-        mongo aodh --eval "db.dropDatabase();"
-    fi
     if [ "$AODH_DEPLOY" == "mod_wsgi" ]; then
         _aodh_cleanup_apache_wsgi
     fi
@@ -182,11 +142,6 @@ function cleanup_aodh {
 function _aodh_configure_storage_backend {
     if [ "$AODH_BACKEND" = 'mysql' ] || [ "$AODH_BACKEND" = 'postgresql' ] ; then
         iniset $AODH_CONF database connection $(database_connection_url aodh)
-    elif [ "$AODH_BACKEND" = 'mongodb' ] ; then
-        iniset $AODH_CONF database connection mongodb://localhost:27017/aodh
-        cleanup_aodh
-    elif [ "$AODH_BACKEND" = 'hbase' ] ; then
-        iniset $AODH_CONF database connection hbase://__test__
     else
         die $LINENO "Unable to configure unknown AODH_BACKEND $AODH_BACKEND"
     fi
@@ -213,13 +168,6 @@ function configure_aodh {
         setup_colorized_logging $AODH_CONF DEFAULT
     fi
 
-    # Install the policy file for the API server
-    cp $AODH_DIR/etc/aodh/policy.json $AODH_CONF_DIR
-    iniset $AODH_CONF oslo_policy policy_file $AODH_CONF_DIR/policy.json
-
-    cp $AODH_DIR/etc/aodh/api_paste.ini $AODH_CONF_DIR
-    cp $AODH_DIR/etc/aodh/aodh-config-generator.conf $AODH_CONF_DIR
-
     # The alarm evaluator needs these options to call gnocchi/ceilometer APIs
     iniset $AODH_CONF service_credentials auth_type password
     iniset $AODH_CONF service_credentials username aodh
@@ -238,7 +186,6 @@ function configure_aodh {
     # NOTE: This must come after database configuration as those can
     # call cleanup_aodh which will wipe the WSGI config.
     if [ "$AODH_DEPLOY" == "mod_wsgi" ]; then
-        iniset $AODH_CONF api pecan_debug "False"
         _aodh_config_apache_wsgi
     elif [ "$AODH_DEPLOY" == "uwsgi" ]; then
         # iniset creates these files when it's called if they don't exist.
@@ -291,9 +238,14 @@ function init_aodh {
 # otherwise makes sense to do the backend services).
 function install_aodh {
     _aodh_prepare_coordination
-    _aodh_prepare_storage_backend
     install_aodhclient
-    sudo -H pip install -e "$AODH_DIR"[test,$AODH_BACKEND]
+    if python3_enabled; then
+        PY_VERS=${PYTHON3_VERSION}
+    else
+        PY_VERS=${PYTHON2_VERSION}
+    fi
+    sudo -H SETUPTOOLS_USE_DISTUTILS=stdlib python${PY_VERS} -m pip \
+	    install -e "$AODH_DIR"[test,$AODH_BACKEND]
     sudo install -d -o $STACK_USER -m 755 $AODH_CONF_DIR
 
     if [ "$AODH_DEPLOY" == "mod_wsgi" ]; then
@@ -340,6 +292,15 @@ function start_aodh {
     run_process aodh-listener "$AODH_BIN_DIR/aodh-listener --config-file $AODH_CONF"
 }
 
+# configure_tempest_for_aodh()
+# NOTE (gmann): Configure all the Tempest setting for Aodh service in
+# this function.
+function configure_tempest_for_aodh {
+    if is_service_enabled tempest; then
+        iniset $TEMPEST_CONFIG service_available aodh True
+    fi
+}
+
 # stop_aodh() - Stop running processes
 function stop_aodh {
     if [ "$AODH_DEPLOY" == "mod_wsgi" ]; then
@@ -360,7 +321,7 @@ if is_service_enabled aodh; then
         preinstall_aodh
     elif [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Aodh"
-        # Use stack_install_service here to account for vitualenv
+        # Use stack_install_service here to account for virtualenv
         stack_install_service aodh
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         echo_summary "Configuring Aodh"
@@ -371,6 +332,9 @@ if is_service_enabled aodh; then
         init_aodh
         # Start the services
         start_aodh
+    elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
+        echo_summary "Configuring Tempest for Aodh"
+        configure_tempest_for_aodh
     fi
 
     if [[ "$1" == "unstack" ]]; then
